import React, { useState, useEffect } from "react";
import LeftNavigationUiConfiguratorTest from "./LeftNavigationUiConfiguratorTest";
import { Form, Row, Col, Button, Table } from "react-bootstrap";
import { FaEdit, FaUserAlt, FaBan } from "react-icons/fa";
import { Link, NavLink } from "react-router-dom";
import Alert from "react-bootstrap/Alert";
import axios from "axios";
import { useLocation } from "react-router-dom";

function UpdatePlanetVhostTest(props) {
  const location = useLocation();
  const [planetVhostInfoData, setPlanetVhostInfoData] = useState({
    id: "",
    envName: "",
    name: "",
    protocol: "",
    port: "",
    cname: "",
  });

  //load existing planet vhost details
  useEffect(() => {
    axios
      .get(
        `https://configurator-api-m7mkmev5sq-uc.a.run.app/vhost/${new URLSearchParams(
          location.search
        ).get("vhostId")}`
      )
      .then((response) => {
        setPlanetVhostInfoData({
          id: response.data.id,
          envName: response.data.envName,
          name: response.data.name,
          protocol: response.data.protocol,
          port: response.data.port,
          cname: response.data.cname,
        });
      })
      .catch((error) => {
        <Alert variant={"danger"}>{error.message}</Alert>;
      });
  }, []);

  //vhost environment name change
  const handlePlanetVhostEnvChange = (e) => {
    let temp = { ...planetEnvInfoData };
    temp[e.target.name] = e.target.value;
    setPlanetEnvInfoData(temp);
  };

  //vhost name change
  const handlePlanetVhostNameChange = (e) => {
    let temp = { ...planetVhostInfoData };
    temp[e.target.name] = e.target.value;
    setPlanetVhostInfoData(temp);
  };

  //vhost protocol change
  const handlePlanetVhostProtocolChange = (e) => {
    let temp = { ...planetVhostInfoData };
    temp[e.target.name] = e.target.value;
    setPlanetVhostInfoData(temp);
  };

  //vhost port change
  const handlePlanetVhostPortChange = (e) => {
    let temp = { ...planetVhostInfoData };
    temp[e.target.name] = e.target.value;
    setPlanetVhostInfoData(temp);
  };

  //vhost cname change
  const handlePlanetVhostCnameChange = (e) => {
    let temp = { ...planetVhostInfoData };
    temp[e.target.name] = e.target.value;
    setPlanetVhostInfoData(temp);
  };

  //submit handler
  const updatePlanetVhostSubmitHandler = (e) => {
    console.log(planetVhostInfoData);
    axios
      .put(
        `https://configurator-api-m7mkmev5sq-uc.a.run.app/vhost/${new URLSearchParams(
          location.search
        ).get("vhostId")}`,
        planetVhostInfoData
      )
      .then((res) => {
        <Alert variant={"success"}>
          {"Host configuration updated successfully"}
        </Alert>;
      })
      .catch((err) => {
        <Alert variant={"danger"}>{err.message}</Alert>;
      });
  };

  return (
    <section>
      <div className="developer-list-page">
        <div className="container">
          <div className="col-sm-12">
            <h2>Update Planet Vhost Info</h2>
            <ul className="breadcrumb">
              <li className="breadcrumb-item">
                <a href="/">Home</a>
              </li>
              <li className="breadcrumb-item active">
                <a href="/">Update Planet Vhost Info</a>
              </li>
            </ul>
          </div>
        </div>
      </div>
      <main id="main mt-5">
        <section id="subpage" className="wow fadeInUp">
          <div className="upload-swagger">
            <div className="container">
              <div className="row form-section nopadding">
                <div className="col-lg-3">{props.leftNavigation}</div>
                <div className="col-lg-9 col-sm-12 swag-border-left">
                  <div className="pageHeaders">
                    <div className="mb-3">
                      <Form>
                        <Form.Group as={Row} controlId="planetHostEnvName">
                          <Form.Label column sm={2}>
                            Host Env Name{" "}
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="envName"
                              onChange={handlePlanetVhostEnvChange}
                              value={planetVhostInfoData.envName}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="planetHostName">
                          <Form.Label column sm={2}>
                            Host Name{" "}
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="name"
                              onChange={handlePlanetVhostNameChange}
                              value={planetVhostInfoData.name}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="planetHostProtocolName">
                          <Form.Label column sm={2}>
                            Protocol{" "}
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="protocol"
                              onChange={handlePlanetVhostProtocolChange}
                              value={planetVhostInfoData.protocol}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="planetHostPortName">
                          <Form.Label column sm={2}>
                            Port{" "}
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="port"
                              onChange={handlePlanetVhostPortChange}
                              value={planetVhostInfoData.port}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="planetHostCnameName">
                          <Form.Label column sm={2}>
                            CName{" "}
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="cname"
                              onChange={handlePlanetVhostCnameChange}
                              value={planetVhostInfoData.cname}
                            />
                          </Col>
                        </Form.Group>
                      </Form>

                      <br />
                      <br />
                      <Button
                        variant="primary"
                        onClick={updatePlanetVhostSubmitHandler}
                      >
                        Update
                      </Button>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </section>
      </main>
    </section>
  );
}

export default UpdatePlanetVhostTest;
